Enum GlobalAccountDataEventType
#[non_exhaustive]pub enum GlobalAccountDataEventType {
Show 13 variants
Direct,
IdentityServer,
InvitePermissionConfig,
IgnoredUserList,
PushRules,
SecretStorageDefaultKey,
SecretStorageKey(String),
MediaPreviewConfig,
UnstableMediaPreviewConfig,
AccountImagePack,
ImagePackRooms,
RecentEmoji,
KeyBackup,
}Expand description
The type of GlobalAccountDataEvent this is.
This type can hold an arbitrary string. To build events with a custom type, convert it
from a string with ::from() / .into(). To check for events that are not available as a
documented variant here, use its string representation, obtained through .to_string().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Direct
m.direct
IdentityServer
m.identity_server
InvitePermissionConfig
m.invite_permission_config
IgnoredUserList
m.ignored_user_list
PushRules
m.push_rules
SecretStorageDefaultKey
m.secret_storage.default_key
SecretStorageKey(String)
m.secret_storage.key.*
MediaPreviewConfig
unstable-msc4278 only.m.media_preview_config
UnstableMediaPreviewConfig
unstable-msc4278 only.io.element.msc4278.media_preview_config
AccountImagePack
unstable-msc2545 only.m.image_pack
This variant uses the unstable type im.ponies.user_emotes.
This variant can also be deserialized from the m.image_pack type.
ImagePackRooms
unstable-msc2545 only.m.image_pack.rooms
This variant uses the unstable type im.ponies.emote_rooms.
This variant can also be deserialized from the m.image_pack.rooms type.
RecentEmoji
m.recent_emoji
KeyBackup
m.key_backup